@@ -103,3 +103,33 @@ test_that("Factor out declarations", {
   expect_true(inherits(attr(design[[3]], "dots")$declaration, "rs_complete"))
   expect_true(inherits(attr(design[[4]], "dots")$declaration, "ra_complete"))
 })
+
+# two by two: keep/drop standard name/non standard name
+
+test_that("keep/drop options work with diff sampling names", {
+  
+  desgn <- declare_population(N = 10) + NULL 
+  
+  dat1 <- draw_data(desgn + declare_sampling(n = 5))
+  dat2 <- draw_data(desgn + declare_sampling(n = 5, drop_nonsampled = TRUE))
+  dat3 <- draw_data(desgn + declare_sampling(n = 5, drop_nonsampled = FALSE))
+  dat4 <- draw_data(desgn + declare_sampling(n = 5, sampling_variable = "smpld"))
+  dat5 <- draw_data(desgn + declare_sampling(n = 5, sampling_variable = "smpld", drop_nonsampled = TRUE))
+  dat6 <- draw_data(desgn + declare_sampling(n = 5, sampling_variable = "smpld", drop_nonsampled = FALSE))
+  
+  # length, which variables
+  expect_equal(nrow(dat1), 5)
+  expect_equal(nrow(dat2), 5)
+  expect_equal(nrow(dat3), 10)
+  expect_false("S" %in% names(dat1))
+  expect_false("S" %in% names(dat2))
+  expect_true("S" %in% names(dat3))
+  
+  expect_equal(nrow(dat4), 5)
+  expect_equal(nrow(dat5), 5)
+  expect_equal(nrow(dat6), 10)
+  expect_false("smpld" %in% names(dat4))
+  expect_false("smpld" %in% names(dat5))
+  expect_true("smpld" %in% names(dat6))
+  
+})
